Documentation
¶
Overview ¶
Package watches manages the configuration and running of Consul service monitoring
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Name string `mapstructure:"name"`
Poll int `mapstructure:"interval"` // time in seconds
Tag string `mapstructure:"tag"`
DC string `mapstructure:"dc"` // Consul datacenter
// contains filtered or unexported fields
}
Config configures the watch
func NewConfigs ¶
NewConfigs parses json config into a validated slice of Configs
type Watch ¶
Watch represents an event to signal when something changes
func FromConfigs ¶
FromConfigs creates Watches from a slice of validated Configs
func (*Watch) CheckForUpstreamChanges ¶
CheckForUpstreamChanges checks the service discovery endpoint for any changes in a dependent backend. Returns true when there has been a change.
Click to show internal directories.
Click to hide internal directories.